@@ -82,7 +82,7 @@ class Simuwater:
         runoffErr = ctypes.c_float()
         flowErr = ctypes.c_float()
         qualErr = ctypes.c_float()
-        err_code = self._simuwater.swmm_getMassBalErr(ctypes.byref(runoffErr),
+        err_code = self._simuwater.simuwater_getMassBalErr(ctypes.byref(runoffErr),
                                                      ctypes.byref(flowErr), 
                                                      ctypes.byref(qualErr))
         return err_code, runoffErr.value, flowErr.value, qualErr.value
@@ -163,7 +163,14 @@ class Simuwater:
         return self._simuwater.simuwater_setSwmmSetting(inp_id.encode('utf-8'),
                                                         obj_id.encode('utf-8'),
                                                         ctypes.c_double(setting_value))
-        
+
+    def simuwater_getSwmmSetting(self, inp_id, obj_id):
+        setting_value = ctypes.c_double()
+        err_code = self._simuwater.simuwater_getSwmmCurrentSetting(inp_id.encode('utf-8'),
+                                                                   obj_id.encode('utf-8'),
+                                                                   ctypes.byref(setting_value))
+        return err_code, setting_value.value
+
     def simuwater_getSwmmResult(self, inp_id, obj_type, obj_id, var_type):
         result_value = ctypes.c_double()
         err_code = self._simuwater.simuwater_getSwmmResult(inp_id.encode('utf-8'),
